/*----------------------------------------------------------------------
  File    : menu.h
  Contents: simplified menu definition for Athena widgets
  Author  : Christian Borgelt
  History : 1998.04.11 file created
            1998.04.16 first version completed
            2001.06.04 function mn_minwidth added
----------------------------------------------------------------------*/
#ifndef __MENU__
#define __MENU__
#include <X11/Intrinsic.h>

/*----------------------------------------------------------------------
  Preprocessor Definitions
----------------------------------------------------------------------*/
/* --- parameter type of functions mn_visible and mn_enable --- */
#define MN_MENU      0x01        /* enable/disable menu as a whole */
#define MN_TITLES    0x02        /* enable/disable menu titles */
#define MN_ITEMS     0x04        /* enable/disable menu items */

/*----------------------------------------------------------------------
  Type Definitions
----------------------------------------------------------------------*/
typedef struct {                 /* --- a menu title --- */
  Widget    title;               /* menu title widget */
  Widget    pane;                /* items pane widget */
  int       flags;               /* enable/visible flags */
} MNTITLE;                       /* (menu title) */

typedef struct {                 /* --- a menu item --- */
  Widget    item;                /* item widget */
  int       flags;               /* enable/visible flags */
} MNITEM;                        /* (menu item) */

typedef struct {                 /* --- a menu --- */
  Widget    parent;              /* parent widget */
  Widget    menubar;             /* menu bar (a box widget) */
  MNTITLE   *titles;             /* menu titles */
  int       titlevsz;            /* size of menu titles vector */
  int       titlecnt;            /* number of menu titles */
  MNITEM    *items;              /* menu items */
  int       itemvsz;             /* size of menu items vector */
  int       itemcnt;             /* number of menu items */
  Widget    filler;              /* filler entry for menu bar */
  Dimension width, height;       /* width and height of menu */
  Dimension mnwd;                /* width of menu titles */
} MENU;                          /* (menu) */

/*----------------------------------------------------------------------
  Functions
----------------------------------------------------------------------*/
extern MENU*     mn_create   (Widget parent);
extern void      mn_delete   (MENU *menu);
extern Widget    mn_menubar  (MENU *menu);
extern Dimension mn_minwidth (MENU *menu);
extern Dimension mn_width    (MENU *menu);
extern Dimension mn_height   (MENU *menu);
extern int       mn_addtitle (MENU *menu, const char *name, int flags,
                              XtCallbackProc proc, XtPointer data);
extern int       mn_additem  (MENU *menu, const char *name, int flags,
                              XtCallbackProc proc, XtPointer data);
extern void      mn_visible  (MENU *menu, int type, int flags);
extern void      mn_enable   (MENU *menu, int type, int flags);
extern int       mn_info     (MENU *menu, const char *text);
extern int       mn_resize   (MENU *menu, Dimension width);

/*----------------------------------------------------------------------
  Preprocessor Definitions
----------------------------------------------------------------------*/
#define mn_minwidth(m)    ((m)->mnwd +1)
#define mn_width(m)       ((m)->width)
#define mn_height(m)      ((m)->height)
#define mn_menubar(m)     ((m)->menubar)

#endif

